==> ripe-dbase-2.1.tar.gz: src/adderror.pl <==
# adderror.pl
#
# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
#
# All Rights Reserved
#
# Permission to use, copy, modify, and distribute this software and its
# documentation for any purpose and without fee is hereby granted,
# provided that the above copyright notice appear in all copies and that
# both that copyright notice and this permission notice appear in
# supporting documentation, and that the name of the author not be
# used in advertising or publicity pertaining to distribution of the
# software without specific, written prior permission.
#
# THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
# ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
# AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
# DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
# AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
# $Id: adderror.pl,v 2.1 1997/10/02 15:25:40 chris Exp $
#
#	$RCSfile: adderror.pl,v $
#	$Revision: 2.1 $
#	$Author: chris $
#	$Date: 1997/10/02 15:25:40 $


sub adderror {
    local(*object, $msg) = @_;
    
    local($*)=1;
    $msg=~ s/^\n+//;
    $msg=~ s/\n+$//;
    
    $object{"ue"}.="\n" if ($object{"ue"});
    $object{"ue"}.=$msg;
    
}

sub addwarning {
    local(*object, $msg) = @_;
    
    local($*)=1;
    $msg=~ s/^\n+//;
    $msg=~ s/\n+$//;
    
    $object{"uw"}.="\n" if ($object{"uw"});
    $object{"uw"}.=$msg;

}


sub haserror {
    local(*object)=@_;

    print STDERR "haserror: defined: ", defined($object{"ue"}), " ue: ", $object{"ue"}, "\n" if ($opt_V);

    return defined($object{"ue"});
}

sub haswarning {
    local(*object) = @_;

    return defined($object{"uw"});
}

sub rmerrors {
    local(*object)=@_;
    
    delete $object{"ue"};

}

sub rmwarnings {
    local(*object) = @_;

    delete $object{"uw"};

}

1;

==> ripe-dbase-2.2.tar.gz: src/adderror.pl <==
# adderror.pl
#
# Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
# Copyright (c) 1998                              RIPE NCC
#
# All Rights Reserved
#
# Permission to use, copy, modify, and distribute this software and its
# documentation for any purpose and without fee is hereby granted,
# provided that the above copyright notice appear in all copies and that
# both that copyright notice and this permission notice appear in
# supporting documentation, and that the name of the author not be
# used in advertising or publicity pertaining to distribution of the
# software without specific, written prior permission.
#
# THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
# ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
# AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
# DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
# AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
# $Id: adderror.pl,v 2.2.2.4 1998/11/25 10:59:00 roman Exp $
#
#	$RCSfile: adderror.pl,v $
#	$Revision: 2.2.2.4 $
#	$Author: roman $
#	$Date: 1998/11/25 10:59:00 $

require "dpr.pl";

sub adderror {
    local(*object, $msg) = @_;

    return unless defined($msg);
    
    local($*)=1;
    $msg=~ s/^\n+//;
    $msg=~ s/\n+$//;
    
    $object{"ue"}.="\n" if ($object{"ue"});
    $object{"ue"}.=$msg;
    
}

sub addwarning {
    local(*object, $msg) = @_;
    
    return unless defined($msg);
    
    local($*)=1;
    $msg=~ s/^\n+//;
    $msg=~ s/\n+$//;
    
    $object{"uw"}.="\n" if ($object{"uw"});
    $object{"uw"}.=$msg;

}


sub haserror {
    local(*object)=@_;

#    &dpr("haserror: defined: ", defined($object{"ue"}), 
#	 " ue: ", $object{"ue"}, "\n");

    return defined($object{"ue"});
}

sub haswarning {
    local(*object) = @_;

    return defined($object{"uw"});
}

sub rmerrors {
    local(*object)=@_;
    
    delete $object{"ue"};

}

sub rmwarnings {
    local(*object) = @_;

    delete $object{"uw"};

}

1;
